==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/ChunkedInputStream.h <==
// public class gnu.java.net.protocol.http.ChunkedInputStream

// class file dependencies
// @dep_class e241e02307628460 gnu_java_net_protocol_http_ChunkedInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_protocol_http_ChunkedInputStream_H_
#define _JC_gnu_java_net_protocol_http_ChunkedInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Headers$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_refs	_jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$refs	_jc_gnu_java_net_protocol_http_ChunkedInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$nonrefs	_jc_gnu_java_net_protocol_http_ChunkedInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object	_jc_gnu_java_net_protocol_http_ChunkedInputStream$object;

typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$fields_struct	_jc_gnu_java_net_protocol_http_ChunkedInputStream$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vmethods	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtable	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$fields_struct {
	jbyte	CR;
	jbyte	LF;
};
extern _jc_gnu_java_net_protocol_http_ChunkedInputStream$fields_struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_http_ChunkedInputStream$method$_init$63b1d8dc915ca11f(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_gnu_java_net_protocol_http_Headers$object *);

// Virtual methods
extern jint _jc_gnu_java_net_protocol_http_ChunkedInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *);
extern jint _jc_gnu_java_net_protocol_http_ChunkedInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_byte_array *);
extern jint _jc_gnu_java_net_protocol_http_ChunkedInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_ChunkedInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_protocol_http_ChunkedInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_protocol_http_ChunkedInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *);
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_byte_array *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vmethods	gnu_java_net_protocol_http_ChunkedInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_refs {
	struct _jc_gnu_java_net_protocol_http_Headers$object	*headers;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$refs {
    _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_refs	gnu_java_net_protocol_http_ChunkedInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_nonrefs {
	jint	size;
	jint	count;
	jboolean	meta;
	jboolean	eof;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_nonrefs	gnu_java_net_protocol_http_ChunkedInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object {
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype _jc_gnu_java_net_protocol_http_ChunkedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_ChunkedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_ChunkedInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_ChunkedInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/ChunkedInputStream.h <==
// public class gnu.java.net.protocol.http.ChunkedInputStream

// class file dependencies
// @dep_class e241e02307628460 gnu_java_net_protocol_http_ChunkedInputStream
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_gnu_java_net_protocol_http_ChunkedInputStream_H_
#define _JC_gnu_java_net_protocol_http_ChunkedInputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Headers$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_refs	_jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_nonrefs	_jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$refs	_jc_gnu_java_net_protocol_http_ChunkedInputStream$refs;
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$nonrefs	_jc_gnu_java_net_protocol_http_ChunkedInputStream$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object	_jc_gnu_java_net_protocol_http_ChunkedInputStream$object;

typedef struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$fields_struct	_jc_gnu_java_net_protocol_http_ChunkedInputStream$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vmethods	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtable	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$fields_struct {
	jbyte	CR;
	jbyte	LF;
};
extern _jc_gnu_java_net_protocol_http_ChunkedInputStream$fields_struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_http_ChunkedInputStream$method$_init$63b1d8dc915ca11f(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_gnu_java_net_protocol_http_Headers$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_net_protocol_http_ChunkedInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_ChunkedInputStream$method$read$c38dd905b7fb8654(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_http_ChunkedInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_ChunkedInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_gnu_java_net_protocol_http_ChunkedInputStream$method_info$read$c38dd905b7fb8654;
extern _jc_method _jc_gnu_java_net_protocol_http_ChunkedInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$c38dd905b7fb8654)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vmethods	gnu_java_net_protocol_http_ChunkedInputStream;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_refs {
	struct _jc_gnu_java_net_protocol_http_Headers$object	*headers;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$refs {
    _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_refs	gnu_java_net_protocol_http_ChunkedInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_nonrefs {
	jint	size;
	jint	count;
	jboolean	meta;
	jboolean	eof;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_gnu_java_net_protocol_http_ChunkedInputStream$sub_nonrefs	gnu_java_net_protocol_http_ChunkedInputStream;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_ChunkedInputStream$object {
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_ChunkedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_ChunkedInputStream$vtype _jc_gnu_java_net_protocol_http_ChunkedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_ChunkedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_ChunkedInputStream$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_ChunkedInputStream_H_ */
